@@ -33,10 +33,7 @@ def _load_cdll(path, name):
     library_path = os.path.join(path, library_format.format(name, ext_suffix))
 
     try:
-        if(sys.platform.startswith("win")):
-            return WinDLL(library_path) 
-        else:
-            return cdll.LoadLibrary(library_path)
+        return cdll.LoadLibrary(library_path)
     except Exception as ex:
         raise RuntimeError(
             "Failed to load library {}. Attempted to load {}.\n{}".format(
